/*******************************************************************************
* Freescale Semiconductor Inc.
* (c) Copyright 2014 Freescale Semiconductor, Inc.
* ALL RIGHTS RESERVED.
********************************************************************************
Services performed by FREESCALE in this matter are performed AS IS and without
any warranty. CUSTOMER retains the final decision relative to the total design
and functionality of the end product. FREESCALE neither guarantees nor will be
held liable by CUSTOMER for the success of this project.
FREESCALE DISCLAIMS ALL WARRANTIES, EXPRESSED, IMPLIED OR STATUTORY INCLUDING,
BUT NOT LIMITED TO, IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
A PARTICULAR PURPOSE ON ANY HARDWARE, SOFTWARE ORE ADVISE SUPPLIED TO THE PROJECT
BY FREESCALE, AND OR NAY PRODUCT RESULTING FROM FREESCALE SERVICES. IN NO EVENT
SHALL FREESCALE BE LIABLE FOR INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF
THIS AGREEMENT.
CUSTOMER agrees to hold FREESCALE harmless against any and all claims demands or
actions by anyone on account of any damage, or injury, whether commercial,
contractual, or tortuous, rising directly or indirectly as a result of the advise
or assistance supplied CUSTOMER in connection with product, services or goods
supplied under this Agreement.
********************************************************************************
* File FXAS21000.h
* Owner b35804
* Version 1.0
* Date Apr-28-2014
* Classification General Business Information
* FXAS21000 memory map
********************************************************************************
* Detailed Description: Register address map of FXAS21000 Xtrinsic 3-Axis 
* Digital Rate Gyroscope
********************************************************************************
Revision History:
Version		 Date		 Author			 Description of Changes
*******************************************************************************/

#ifndef FXAS21000_H_
#define FXAS21000_H_

// FXAS21000 Registers

#define STATUS_REG            0x00		// Alias for DR_STATUS or F_STATUS

#define OUT_X_MSB_REG         0x01		// [7:0] are 8 MSBs of the 14-bit X-axis sample
#define OUT_X_LSB_REG         0x02		// [7:2] are the 6 LSB of 14-bit X-axis sample (1),(2)
#define OUT_Y_MSB_REG         0x03		// [7:0] are 8 MSBs of the 14-bit Y-axis sample
#define OUT_Y_LSB_REG         0x04		// [7:2] are the 6 LSB of 14-bit Y-axis sample (1),(2)
#define OUT_Z_MSB_REG         0x05		// [7:0] are 8 MSBs of the 14-bit Z-axis sample
#define OUT_Z_LSB_REG         0x06		// [7:2] are the 6 LSB of 14-bit Z-axis sample (1),(2),(3)

#define DR_STATUS_REG		  0x07		// Data-ready status information
#define F_STATUS_REG		  0x08		// FIFO status
#define F_SETUP_REG           0x09    	// F_SETUP FIFO Setup Register 
#define F_EVENT_REG	          0x0A    	// FIFO event 
#define INT_SCR_FLAG_REG      0x0B    	// Interrupt event source status flags

#define WHO_AM_I_REG          0x0C    	// WHO_AM_I Device ID Register 

#define CTRL_REG0			  0x0D		// Control register 0: Full-scale range selection, highpass filter control, SPI mode selection
#define RT_CFG				  0x0E		// Rate threshold function configuration
#define RT_SRC				  0x0F		// Rate threshold event flags status register
#define RT_THS				  0x10		// Rate threshold function threshold value register
#define RT_COUNT			  0x11		// Rate threshold function debounce counter

// TEMP Registers (4)
#define TEMP_REG              0x12		// Device temperature, valid range of -128 to 127 °C, with a scaling of 1 °C/LSB.


#define CTRL_REG1             0x13    	// Control register 1: Operating mode, ODR selection, self-test and reset control
#define CTRL_REG2             0x14    	// Control register 2: Interrupt configuration settings

/* 1. Data output LSB registers only contain valid data after a read of the corresponding axis MSB data register.
   2. The two least significant bits of each axes data LSB are not used. Data must be right shifted by two bits in the user
	application to obtain a properly scaled 16-bit 2's compliment rate value.
   3. After this register is read, the next read register by the auto-increment process is STATUS at 0x00.
   4. This register is reset only by a hard reset (POR or assertion of the RST_B pin). A soft reset will not reset this register.
*/
//-------------------------------------------------------------------

#endif /* FXAS21000_H_ */
